@@ -28,9 +28,17 @@ _LOGGER = logging.getLogger(__name__)
 BulbResponse = Dict[str, Any]
 
 
-TIMEOUT = 7
-SEND_INTERVAL = 0.5
-MAX_SEND_DATAGRAMS = int(TIMEOUT / SEND_INTERVAL)
+PORT = 38899
+
+# Progressive backoff config
+# ===============================================================
+# We send datagrams at 0, 0.75, 2.25, 5.25, 8.25, 11.25
+# We wait up to 11s for the last response before declaring failure
+# ================================================================
+TIMEOUT = 13  # How long we will wait total
+MAX_SEND_DATAGRAMS = 6  # The maximum datagrams we send
+FIRST_SEND_INTERVAL = 0.75  # This is the first wait time
+MAX_BACKOFF = 3  # This is how far we will backoff
 
 PUSH_KEEP_ALIVE_INTERVAL = 20
 MAX_TIME_BETWEEN_PUSH = PUSH_KEEP_ALIVE_INTERVAL + TIMEOUT
@@ -88,6 +96,11 @@ def _rgb_in_range_or_raise(rgb: Tuple[Union[float, int], ...]) -> None:
         raise ValueError("Blue is not in range between 0-255.")
 
 
+def _validate_speed_or_raise(speed: int) -> None:
+    if not 10 <= speed <= 200:
+        raise ValueError("Value must be between 10 and 200")
+
+
 class PilotBuilder:
     """Get information from the bulb."""
 
@@ -150,10 +163,9 @@ class PilotBuilder:
         self.pilot_params["c"] = value
 
     def _set_speed(self, value: int) -> None:
-        """Set the color changing speed in precent (0-100)."""
+        """Set the effect changing speed (10-200)."""
         # This applies only to changing effects.
-        if not 0 < value < 101:
-            raise ValueError("Value must be between 0 and 100")
+        _validate_speed_or_raise(value)
         self.pilot_params["speed"] = value
 
     def _set_scene(self, scene_id: int) -> None:
@@ -272,13 +284,17 @@ class PilotParser:
         """Get the color changing speed."""
         return _extract_int(self.pilotResult, "speed")
 
+    def get_scene_id(self) -> Optional[int]:
+        if "schdPsetId" in self.pilotResult:  # rhythm
+            return 1000
+        return self.pilotResult.get("sceneId")
+
     def get_scene(self) -> Optional[str]:
         """Get the current scene name."""
-        if "schdPsetId" in self.pilotResult:  # rhythm
-            return SCENES[1000]
-        if "sceneId" not in self.pilotResult:
+        scene_id = self.get_scene_id()
+        if scene_id is None:
             return None
-        return SCENES.get(self.pilotResult["sceneId"])
+        return SCENES.get(scene_id)
 
     def get_cold_white(self) -> Optional[int]:
         """Get the value of the cold white led."""
@@ -331,13 +347,24 @@ async def _send_udp_message_with_retry(
 ) -> None:
     """Send a UDP message multiple times until we reach the maximum or a response is recieved."""
     data = message.encode("utf-8")
+    send_wait = FIRST_SEND_INTERVAL
+    total_waited = 0.0
     for send in range(MAX_SEND_DATAGRAMS):
         if transport.is_closing() or response_future.done():
             return
         attempt = send + 1
-        _LOGGER.debug("%s: >> %s (%s/%s)", ip, data, attempt, MAX_SEND_DATAGRAMS)
+        _LOGGER.debug(
+            "%s: >> %s (%s/%s) backoff=%s",
+            ip,
+            data,
+            attempt,
+            MAX_SEND_DATAGRAMS,
+            total_waited,
+        )
         transport.sendto(data, (ip, port))
-        await asyncio.sleep(SEND_INTERVAL)
+        await asyncio.sleep(send_wait)
+        total_waited += send_wait
+        send_wait = min(send_wait * 2, MAX_BACKOFF)
 
 
 class wizlight:
@@ -348,7 +375,7 @@ class wizlight:
     def __init__(
         self,
         ip: str,
-        port: int = 38899,
+        port: int = PORT,
         mac: Optional[str] = None,
     ) -> None:
         """Create instance with the IP address of the bulb."""
@@ -395,9 +422,8 @@ class wizlight:
     def register(self) -> None:
         """Call register to keep alive push updates."""
         if self.push_running:
-            asyncio.create_task(
-                self._async_send_register(PushManager().get().register_msg)
-            )
+            push_manager = PushManager().get()
+            asyncio.create_task(self._async_send_register(push_manager.register_msg))
             self.loop.call_later(PUSH_KEEP_ALIVE_INTERVAL, self.register)
 
     async def _async_send_register(self, message: str) -> None:
@@ -523,6 +549,14 @@ class wizlight:
         """Reset the bulb to factory defaults."""
         await self.sendUDPMessage(r'{"method":"reset","params":{}}')
 
+    async def set_speed(self, speed: int) -> None:
+        """Set the effect speed."""
+        # If we have state: True in the setPilot, the speed does not change
+        _validate_speed_or_raise(speed)
+        await self.sendUDPMessage(
+            to_wiz_json({"method": "setPilot", "params": {"speed": speed}})
+        )
+
     async def turn_on(self, pilot_builder: PilotBuilder = PilotBuilder()) -> None:
         """Turn the light on with defined message.
 
