@@ -10,10 +10,12 @@ class WizProtocol(asyncio.DatagramProtocol):
     def __init__(
         self,
         on_response: Callable[[bytes, Tuple[str, int]], None],
+        on_error: Optional[Callable[[Optional[Exception]], None]] = None,
     ) -> None:
         """Init the protocol."""
         self.transport = None
         self.on_response = on_response
+        self.on_error = on_error
 
     def datagram_received(self, data: bytes, addr: Tuple[str, int]) -> None:
         """Trigger on_response."""
@@ -22,6 +24,8 @@ class WizProtocol(asyncio.DatagramProtocol):
     def error_received(self, ex: Optional[Exception]) -> None:
         """Handle error."""
         _LOGGER.debug("WizProtocol error: %s", ex)
+        if self.on_error is not None:
+            self.on_error(ex)
 
     def connection_lost(self, ex: Optional[Exception]) -> None:
         """The connection is lost."""
