@@ -5,26 +5,22 @@ from unittest.mock import patch
 import pytest
 
 from pywizlight import SCENES, PilotBuilder, wizlight
+from pywizlight.bulb import states_match
 from pywizlight.bulblibrary import BulbClass, BulbType, Features, KelvinRange
 from pywizlight.discovery import discover_lights
-from pywizlight.bulb import states_match
 from pywizlight.exceptions import WizLightTimeOutError
 from pywizlight.tests.fake_bulb import startup_bulb
 
 
-@pytest.fixture(scope="module")
-def startup_fake_bulb(request: pytest.FixtureRequest) -> None:
-    shutdown = startup_bulb(module_name="ESP01_SHRGB_03", firmware_version="1.25.0")
-    request.addfinalizer(shutdown)
-
-
 @pytest.fixture()
-async def correct_bulb(
-    startup_fake_bulb: pytest.FixtureRequest,
-) -> AsyncGenerator[wizlight, None]:
-    bulb = wizlight(ip="127.0.0.1")
+async def correct_bulb() -> AsyncGenerator[wizlight, None]:
+    shutdown, port = await startup_bulb(
+        module_name="ESP01_SHRGB_03", firmware_version="1.25.0"
+    )
+    bulb = wizlight(ip="127.0.0.1", port=port)
     yield bulb
     await bulb.async_close()
+    shutdown()
 
 
 @pytest.fixture()
@@ -43,7 +39,7 @@ async def test_Bulb_Discovery(correct_bulb: wizlight) -> None:
     with patch("pywizlight.discovery.PORT", 0):
         bulbs = await discover_lights(broadcast_space="192.168.178.255", wait_time=0.02)
     for bulb in bulbs:
-        with patch("pywizlight.bulb.SEND_INTERVAL", 0.01), patch(
+        with patch("pywizlight.bulb.FIRST_SEND_INTERVAL", 0.01), patch(
             "pywizlight.bulb.TIMEOUT", 0.01
         ):
             state = await bulb.updateState()
@@ -150,6 +146,14 @@ async def test_PilotBuilder_speed(correct_bulb: wizlight) -> None:
     assert state and state.get_speed() == 50
 
 
+@pytest.mark.asyncio
+async def test_set_speed(correct_bulb: wizlight) -> None:
+    """Set speed."""
+    await correct_bulb.set_speed(125)
+    state = await correct_bulb.updateState()
+    assert state and state.get_speed() == 125
+
+
 @pytest.mark.asyncio
 async def test_get_source(correct_bulb: wizlight) -> None:
     """Test getting the source."""
@@ -230,6 +234,13 @@ async def test_error_PilotBuilder_speed(correct_bulb: wizlight) -> None:
         await correct_bulb.turn_on(PilotBuilder(speed=532))
 
 
+@pytest.mark.asyncio
+async def test_error_set_speed(correct_bulb: wizlight) -> None:
+    """Error speed."""
+    with pytest.raises(ValueError):
+        await correct_bulb.set_speed(532)
+
+
 @pytest.mark.asyncio
 async def test_fw_version(correct_bulb: wizlight) -> None:
     """Test fetching the firmware version."""
@@ -260,7 +271,7 @@ async def test_get_mac(correct_bulb: wizlight) -> None:
 async def test_timeout(bad_bulb: wizlight) -> None:
     """Test the timout exception after."""
     with pytest.raises(WizLightTimeOutError), patch(
-        "pywizlight.bulb.SEND_INTERVAL", 0.01
+        "pywizlight.bulb.FIRST_SEND_INTERVAL", 0.01
     ), patch("pywizlight.bulb.TIMEOUT", 0.01):
         await bad_bulb.getBulbConfig()
 
@@ -270,7 +281,7 @@ async def test_timeout_PilotBuilder(bad_bulb: wizlight) -> None:
     """Test Timout for Result."""
     # check if the bulb state it given as bool - mock ?
     with pytest.raises(WizLightTimeOutError), patch(
-        "pywizlight.bulb.SEND_INTERVAL", 0.01
+        "pywizlight.bulb.FIRST_SEND_INTERVAL", 0.01
     ), patch("pywizlight.bulb.TIMEOUT", 0.01):
         await bad_bulb.turn_on(PilotBuilder(brightness=255))
 
