@@ -10,10 +10,10 @@ from pywizlight.tests.fake_bulb import startup_bulb
 
 @pytest.fixture()
 async def light_strip() -> AsyncGenerator[wizlight, None]:
-    shutdown = startup_bulb(
-        module_name="ESP03_SHRGB3_01ABI", firmware_version="1.16.64"
+    shutdown, port = await startup_bulb(
+        module_name="ESP20_SHRGB_01ABI", firmware_version="1.25.0"
     )
-    bulb = wizlight(ip="127.0.0.1")
+    bulb = wizlight(ip="127.0.0.1", port=port)
     yield bulb
     await bulb.async_close()
     shutdown()
@@ -27,16 +27,56 @@ async def test_setting_rgbww(light_strip: wizlight) -> None:
     assert state and state.get_rgbww() == (1, 2, 3, 4, 5)
 
 
+@pytest.mark.asyncio
+async def test_supported_scenes(light_strip: wizlight) -> None:
+    """Test supported scenes."""
+    assert await light_strip.getSupportedScenes() == [
+        "Ocean",
+        "Romance",
+        "Sunset",
+        "Party",
+        "Fireplace",
+        "Cozy",
+        "Forest",
+        "Pastel Colors",
+        "Wake up",
+        "Bedtime",
+        "Warm White",
+        "Daylight",
+        "Cool white",
+        "Night light",
+        "Focus",
+        "Relax",
+        "True colors",
+        "TV time",
+        "Plantgrowth",
+        "Spring",
+        "Summer",
+        "Fall",
+        "Deepdive",
+        "Jungle",
+        "Mojito",
+        "Club",
+        "Christmas",
+        "Halloween",
+        "Candlelight",
+        "Golden white",
+        "Pulse",
+        "Steampunk",
+        "Rhythm",
+    ]
+
+
 @pytest.mark.asyncio
 async def test_model_description_light_strip(light_strip: wizlight) -> None:
     """Test fetching the model description for a light strip."""
     bulb_type = await light_strip.get_bulbtype()
     assert bulb_type == BulbType(
         features=Features(color=True, color_tmp=True, effect=True, brightness=True),
-        name="ESP03_SHRGB3_01ABI",
+        name="ESP20_SHRGB_01ABI",
         kelvin_range=KelvinRange(max=6500, min=2700),
         bulb_type=BulbClass.RGB,
-        fw_version="1.16.64",
-        white_channels=1,
-        white_to_color_ratio=20,
+        fw_version="1.25.0",
+        white_channels=2,
+        white_to_color_ratio=80,
     )
