@@ -10,8 +10,10 @@ from pywizlight.tests.fake_bulb import startup_bulb
 
 @pytest.fixture()
 async def socket() -> AsyncGenerator[wizlight, None]:
-    shutdown = startup_bulb(module_name="ESP10_SOCKET_06", firmware_version="1.25.0")
-    bulb = wizlight(ip="127.0.0.1")
+    shutdown, port = await startup_bulb(
+        module_name="ESP10_SOCKET_06", firmware_version="1.25.0"
+    )
+    bulb = wizlight(ip="127.0.0.1", port=port)
     yield bulb
     await bulb.async_close()
     shutdown()
